@@ -93,6 +93,7 @@ class Moco(object):
         self.Session = models.Session(self)
 
         self.PurchaseCategory = models.PurchaseCategory(self)
+        self.Purchase = models.Purchase(self)
 
         self._requestor = requestor
         self._objector = objector
@@ -116,18 +117,26 @@ class Moco(object):
         if "domain" in self.auth.keys():
             self.domain = self.auth["domain"]
 
-    def request(self, method, path, params=None, data=None, bypass_auth=False):
+    def request(
+        self,
+        method: str,
+        path: str,
+        params: dict = None,
+        data: dict = None,
+        bypass_auth: bool = False,
+        **kwargs
+    ):
         """
-        request the given ressource with the assigned requestor
+        Requests the given resource with the assigned requestor
 
         :param method: HTTP Method (eg. POST, GET, PUT, DELETE)
-        :param path: path of the ressource (e.g. ``/projects``)
+        :param path: path of the resource (e.g. ``/projects``)
         :param params: url parameters (e.g. ``page=1``, query parameters)
         :param data: dictionary with data (http body)
         :param bypass_auth: If authentication checks should be skipped (default False)
 
-        The request will be given to the currently assinged requestor (see :ref:`requestor`).
-        The response will then be given to the currently assinged objector (see :ref:`objector`)
+        The request will be given to the currently assigned requestor (see :ref:`requestor`).
+        The response will then be given to the currently assigned objector (see :ref:`objector`)
 
         The *possibly* modified response will then be returned
         """
@@ -138,16 +147,27 @@ class Moco(object):
         if not bypass_auth:
             self.authenticate()
 
+        # merge headers if set in model
+        headers = self.headers
+        if "headers" in kwargs.keys():
+            print(kwargs["headers"])
+            for key, value in kwargs["headers"].items():
+                headers[key] = value
+
+            print(headers)
+            del kwargs["headers"]
+
+        # pass request making to the requestor object
         if method == "GET":
-            requestor_response = self._requestor.get(full_path, params=params, data=data, headers=self.headers)
+            requestor_response = self._requestor.get(full_path, params=params, data=data, headers=headers, **kwargs)
         elif method == "PUT":
-            requestor_response = self._requestor.put(full_path, params=params, data=data, headers=self.headers)
+            requestor_response = self._requestor.put(full_path, params=params, data=data, headers=headers, **kwargs)
         elif method == "POST":
-            requestor_response = self._requestor.post(full_path, params=params, data=data, headers=self.headers)
+            requestor_response = self._requestor.post(full_path, params=params, data=data, headers=headers, **kwargs)
         elif method == "DELETE":
-            requestor_response = self._requestor.delete(full_path, params=params, data=data, headers=self.headers)
+            requestor_response = self._requestor.delete(full_path, params=params, data=data, headers=headers, **kwargs)
         elif method == "PATCH":
-            requestor_response = self._requestor.patch(full_path, params=params, data=data, headers=self.headers)
+            requestor_response = self._requestor.patch(full_path, params=params, data=data, headers=headers, **kwargs)
 
         # push the response to the current objector
         objector_result = self._objector.convert(requestor_response)
@@ -161,18 +181,33 @@ class Moco(object):
         return objector_result
 
     def get(self, path, params=None, data=None, **kwargs):
+        """
+        Helper function for GET requests
+        """
         return self.request("GET", path, params=params, data=data, **kwargs)
 
     def post(self, path, params=None, data=None, **kwargs):
+        """
+        Helper function for POST requests
+        """
         return self.request("POST", path, params=params, data=data, **kwargs)
 
     def put(self, path, params=None, data=None, **kwargs):
+        """
+        Helper function for PUT requests
+        """
         return self.request("PUT", path, params=params, data=data, **kwargs)
 
     def delete(self, path, params=None, data=None, **kwargs):
+        """
+        Helper function for DELETE requests
+        """
         return self.request("DELETE", path, params=params, data=data, **kwargs)
 
     def patch(self, path, params=None, data=None, **kwargs):
+        """
+        Helper function for PATCH requests
+        """
         return self.request("PATCH", path, params=params, data=data, **kwargs)
 
     def impersonate(
@@ -180,7 +215,7 @@ class Moco(object):
         user_id: int
     ):
         """
-        Impersontates the user with the supplied user id
+        Impersonates the user with the supplied user id
 
         :param user_id: user id to impersonate
 
@@ -236,7 +271,6 @@ class Moco(object):
         """
         Get the http.session object of the current requestor (None if the requestor does not have a session)
         """
-
         return self._requestor.session
 
     @property
@@ -263,9 +297,9 @@ class Moco(object):
 
     def authenticate(self):
         """
-        Performs any action neccessary to be authenticated against the moco api.
+        Performs any action necessary to be authenticated against the moco api.
 
-        This method gets invoked automaticly, on the very first request you send against the api.
+        This method gets invoked automatically, on the very first request you send against the api.
         """
         if self.api_key is not None and self.domain is not None:
             return  # already authenticated
@@ -285,5 +319,5 @@ class Moco(object):
             self.api_key = session.api_key
             del self.auth
         else:
-            # raise error authentication information is very likely invlid
+            # raise error authentication information is very likely invalid
             raise ValueError("Invalid authentication information given")
