@@ -5,9 +5,11 @@ from moco_wrapper.const import API_PATH
 
 from enum import Enum
 
+
 class ActivityRemoteService(str, Enum):
     """
-    Enumeration for allowed values used that can be supplied for the ``remote_service`` argument in :meth:`.Activity.create` and :meth:`.Activity.update`
+    Enumeration for allowed values used that can be supplied for the ``remote_service`` argument in
+    :meth:`.Activity.create` and :meth:`.Activity.update`
 
     .. code-block:: python
 
@@ -37,13 +39,15 @@ class ActivityRemoteService(str, Enum):
 class Activity(MWRAPBase):
     """
     Class for handling activities.
-    
-    Activities are always created for a project task. The order of things is `Project>Task>Activity`. An activity always belongs to a task and that task always belongs to a project.
+
+    Activities are always created for a project task. The order of things is `Project>Task>Activity`. An activity always
+    belongs to a task and that task always belongs to a project.
 
     Example Usage:
 
     .. code-block:: python
 
+        import datetime
         from moco_wrapper import Moco
 
         m = Moco()
@@ -58,7 +62,7 @@ class Activity(MWRAPBase):
             0.25
             description="did things"
         )
-        
+
     """
 
     def __init__(self, moco):
@@ -79,17 +83,17 @@ class Activity(MWRAPBase):
         sort_by: str = None,
         sort_order: str = 'asc',
         page: int = 1,
-        ):
+    ):
         """
-        Get a list of activity objects.
+        Get a list of activities.
 
         :param from_date: Start date
         :param to_date: End date
-        :param user_id: User id of the creator
-        :param project_id: Id of the project the activity belongs to
-        :param task_id: Id of the task the activity belongs t
-        :param sort_by: Field to sort results by
-        :param sort_order: asc or desc
+        :param user_id: User Id the activity belongs to (default ``None``)
+        :param project_id: Id of the project the activity belongs to (default ``None``)
+        :param task_id: Id of the task the activity belongs to (default ``None``)
+        :param sort_by: Field to sort results by (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
         :param page: Page number (default 1)
 
         :type from_date: datetime.date, str
@@ -102,6 +106,7 @@ class Activity(MWRAPBase):
         :type page: int
 
         :returns: List of activities
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
 
         if task_id is not None and project_id is None:
@@ -114,12 +119,11 @@ class Activity(MWRAPBase):
         else:
             params["from"] = from_date
 
-        if isinstance(to_date,  datetime.date):
+        if isinstance(to_date, datetime.date):
             params["to"] = self._convert_date_to_iso(to_date)
         else:
             params["to"] = to_date
 
-
         for key, value in (
             ("user_id", user_id),
             ("project_id", project_id),
@@ -137,15 +141,16 @@ class Activity(MWRAPBase):
     def get(
         self,
         activity_id: int
-        ):
+    ):
         """
         Get a single activity.
 
-        :param activity_id: Id of the activity:
+        :param activity_id: Id of the activity
 
         :type activity_id: int
 
         :returns: The activity object
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         return self._moco.get(API_PATH["activity_get"].format(id=activity_id))
@@ -162,20 +167,21 @@ class Activity(MWRAPBase):
         remote_service: str = None,
         remote_id: int = None,
         remote_url: str = None
-        ):
+    ):
         """
         Create an activity.
 
-        :param activity_date: date of the activity
-        :param project_id: id of the project this activity belongs to
-        :param task_id: id of the task this activity belongs to (see project tasks)
-        :param hours: hours to log to the activity (passing a 0 will start a timer if the date is today)
-        :param description: activity description text
-        :param billable: true/false (if this activity is billable) (select none if billing is dependent on project configuration)
-        :param tag: a tag string
-        :param remote_service: if this task was created by a remote service, its name will be here.
-        :param remote_id: id of the activity in the remote_service
-        :param remote_url: address of the remote service
+        :param activity_date: Date of the activity
+        :param project_id: Id of the project this activity belongs to
+        :param task_id: Id of the task this activity belongs to
+        :param hours: Hours to log to the activity (pass 0 to start a timer, if the date is today)
+        :param description: Activity description text (default ``None``)
+        :param billable: If this activity is billable
+            (pass ``None`` if billing is dependent on project configuration) (default ``None``)
+        :param tag: Tag string (default ``None``)
+        :param remote_service: Name of the remote service referenced by the activity (default ``None``)
+        :param remote_id: Id of the activity in the remote_service (default ``None``)
+        :param remote_url: Url of the remote service (default ``None``)
 
         :type activity_date: datetime.date, str
         :type project_id: int
@@ -188,15 +194,16 @@ class Activity(MWRAPBase):
         :type remote_id: str
         :type remote_url: str
 
-        :returns: the created activity
+        :returns: The created activity
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         data = {
             "project_id": project_id,
-            "task_id" : task_id,
+            "task_id": task_id,
             "hours": hours,
         }
-    
+
         if isinstance(activity_date, datetime.date):
             data["date"] = self._convert_date_to_iso(activity_date)
         else:
@@ -228,21 +235,22 @@ class Activity(MWRAPBase):
         remote_service: str = None,
         remote_id: int = None,
         remote_url: str = None
-        ):
+    ):
         """
-        Create an activity.
+        Update an activity.
 
-        :param activity_id: id of the activity
-        :param activity_date: date of the activity
-        :param project_id: id of the project this activity belongs to
-        :param task_id: id of the task this activity belongs to (see project tasks)
-        :param hours: hours to log to the activity (passing a 0 will start a timer if the date is today)
-        :param description: activity description text
-        :param billable: true/false (if this activity is billable) (select none if billing is dependent on project configuration)
-        :param tag: a tag string
-        :param remote_service: if this task was created by a remote service, its name will be here
-        :param remote_id: id of the activity in the remote_service
-        :param remote_url: address of the remote service
+        :param activity_id: Id of the activity
+        :param activity_date: Date of the activity
+        :param project_id: Id of the project this activity belongs to
+        :param task_id: Id of the task this activity belongs to
+        :param hours: hours to log to the activity (pass 0 to start a timer, if the date is today)
+        :param description: Description text (default ``None``)
+        :param billable: If this activity is billable
+            (pass ``None``) if billing is dependent on project configuration) (default ``None``)
+        :param tag: Tag string (default ``None``)
+        :param remote_service: Name of the remote service referenced by the activity (default ``None``)
+        :param remote_id: Id of the activity in the remote_service (default ``None``)
+        :param remote_url: Url of the remote service (default ``None``)
 
         :type activity_id: int
         :type activity_date: datetime.date, str
@@ -256,7 +264,8 @@ class Activity(MWRAPBase):
         :type remote_id: str
         :type remote_url: str
 
-        :returns: the updated activity
+        :returns: The updated activity
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         data = {}
@@ -283,17 +292,18 @@ class Activity(MWRAPBase):
     def start_timer(
         self,
         activity_id: int
-        ):
+    ):
         """
         Start a timer on the specified activity.
 
-        The timer can only be started for activities on the current day.
+        Timers can only be started for activities of the current day.
 
-        :param activity_id: id of the activity
+        :param activity_id: Id of the activity
 
         :type activity_id: int
 
-        :returns: the activity the timer was started for
+        :returns: The activity the timer was started for
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         return self._moco.patch(API_PATH["activity_start_timer"].format(id=activity_id))
@@ -301,7 +311,7 @@ class Activity(MWRAPBase):
     def stop_timer(
         self,
         activity_id: int
-        ):
+    ):
         """
         Stop a timer on the specified activity.
 
@@ -309,7 +319,8 @@ class Activity(MWRAPBase):
 
         :type activity_id: int
 
-        :returns: the activity the timer was stopped for
+        :returns: The activity the timer was stopped for
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         return self._moco.patch(API_PATH["activity_stop_timer"].format(id=activity_id))
@@ -317,7 +328,7 @@ class Activity(MWRAPBase):
     def delete(
         self,
         activity_id: int
-        ):
+    ):
         """
         Delete an activity.
 
@@ -325,25 +336,26 @@ class Activity(MWRAPBase):
 
         :type activity_id: int
 
-        :returns: empty response on success
+        :returns: Empty response on success
+        :rtype: :class:`moco_wrapper.util.response.EmptyResponse`
         """
 
         return self._moco.delete(API_PATH["activity_delete"].format(id=activity_id))
 
     def disregard(
         self,
-        reason,
-        activity_ids,
-        company_id,
-        project_id = None
-        ):
+        reason: str,
+        activity_ids: list,
+        company_id: int,
+        project_id: int = None
+    ):
         """
         Disregard activities.
 
         :param reason: Reason text for disregarding these activities
         :param activity_ids: List of activity ids to disregard
         :param company_id: Company id these activities belong to
-        :param project_id: Project id these activities belong to  
+        :param project_id: Project id these activities belong to (default ``None``)
 
         :type reason: str
         :type activity_ids: list
@@ -351,13 +363,14 @@ class Activity(MWRAPBase):
         :type project_id: int
 
         :returns: List with the activity ids that were disregarded
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
 
         data = {
-            "reason" : reason,
-            "activity_ids" : activity_ids,
+            "reason": reason,
+            "activity_ids": activity_ids,
             "company_id": company_id,
-        }  
+        }
 
         for key, value in (
             ("project_id", project_id),
