@@ -8,7 +8,8 @@ from enum import Enum
 
 class InvoiceStatus(str, Enum):
     """
-    Enumeration for allowed values that can be supplied for the ``status`` argument of :meth:`Invoice.getlist`, :meth:`Invoice.update_status` and :meth:`Invoice.create`.
+    Enumeration for allowed values that can be supplied for the ``status`` argument of :meth:`.Invoice.getlist`,
+    :meth:`.Invoice.update_status` and :meth:`.Invoice.create`.
 
     Example usage:
 
@@ -32,13 +33,13 @@ class InvoiceStatus(str, Enum):
     IGNORED = "ignored"
     """
     .. warning::
-        Do not use this status for creating invoices, only updating and filtering
+        Do not use ``IGNORED`` for creating invoices, only updating and filtering.
     """
 
 
 class InvoiceChangeAddress(str, Enum):
     """
-    Enumeration for allowed values that can be supplied for ``change_address`` argument of :meth:`Invoice.create`.
+    Enumeration for allowed values that can be supplied for ``change_address`` argument of :meth:`.Invoice.create`.
 
     .. code-block:: python
 
@@ -85,15 +86,15 @@ class Invoice(MWRAPBase):
         """
         Retrieve a list of invoices.
 
-        :param status: State of the invoice
-        :param date_from: Starting date
-        :param date_to: End date
-        :param tags: List of tags
-        :param identifier: Identifier string (e.g. R1903-003)
-        :param term: Wildcard search term
-        :param sort_by: Field to sort results by
-        :param sort_order: asc or desc (default asc)
-        :param page: Page number (default 1)
+        :param status: State of the invoice (default ``None``)
+        :param date_from: Starting date (default ``None``)
+        :param date_to: End date (default ``None``)
+        :param tags: List of tags (default ``None``)
+        :param identifier: Identifier string (e.g. R1903-003) (default ``None``)
+        :param term: Wildcard search term (default ``None``)
+        :param sort_by: Field to sort results by (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
+        :param page: Page number (default ``1``)
 
         :type status: :class:`.InvoiceStatus`, str
         :type date_from: datetime.date, str
@@ -106,6 +107,7 @@ class Invoice(MWRAPBase):
         :type page: int
 
         :returns: List of invoice objects
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
         params = {}
         for key, value in (
@@ -144,13 +146,13 @@ class Invoice(MWRAPBase):
         """
         Retrieve a list of locked invoices.
 
-        :param status: State of the invoice
-        :param date_from: Start date
-        :param date_to: End date
-        :param identifier: Identifier string (ex. R1903-003)
-        :param sort_by: Field to sort results by
-        :param sort_order: asc or desc (default asc)
-        :param page: Page number (default 1)
+        :param status: State of the invoice (default ``None``)
+        :param date_from: Start date (default ``None``)
+        :param date_to: End date (default ``None``)
+        :param identifier: Identifier string (ex. R1903-003) (default ``None``)
+        :param sort_by: Field to sort results by (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
+        :param page: Page number (default ``1``)
 
         :type status: :class:`.InvoiceStatus`, str
         :type date_from: datetime.date, str
@@ -161,6 +163,7 @@ class Invoice(MWRAPBase):
         :type page: int
 
         :returns: List of invoice objects
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
         params = {}
         for key, value in (
@@ -193,6 +196,7 @@ class Invoice(MWRAPBase):
         :type invoice_id: int
 
         :returns: Single invoice object
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
         return self._moco.get(API_PATH["invoice_get"].format(id=invoice_id))
 
@@ -208,6 +212,7 @@ class Invoice(MWRAPBase):
         :type invoice_id: int
 
         :returns: Invoice pdf
+        :rtype: :class:`moco_wrapper.util.response.FileResponse`
         """
         return self._moco.get(API_PATH["invoice_pdf"].format(id=invoice_id))
 
@@ -218,13 +223,16 @@ class Invoice(MWRAPBase):
         """
         Retrieve the invoice timesheet document as pdf.
 
-        Invoices that have timesheets cannot be created with the api and must be created manully by billing unbilled tasks.
+        .. note::
+            Invoices that have timesheets cannot be created over the api and must be created manually
+            by billing unbilled tasks.
 
         :param invoice_id: Invoice id
 
         :type invoice_id: int
 
         :return: Invoice timesheet as pdf
+        :rtype: :class:`moco_wrapper.util.response.FileResponse`
         """
         return self._moco.get(API_PATH["invoice_timesheet"].format(id=invoice_id))
 
@@ -243,6 +251,7 @@ class Invoice(MWRAPBase):
         :type status: :class:`.InvoiceStatus`, str
 
         :return: Empty response on success
+        :rtype: :class:`moco_wrapper.util.response.EmptyResponse`
         """
         data = {
             "status": status
@@ -276,7 +285,7 @@ class Invoice(MWRAPBase):
         Creates a new invoice.
 
         :param customer_id: Id of the customer/company
-        :param recipient_address: Entry text for the customer (e.g. "My Customer\\\\nMainStreet 5\\\\nExample Town")
+        :param recipient_address: Customers address
         :param created_date: Creation date of the invoice
         :param due_date: Date the invoice is due
         :param service_period_from: Service period start date
@@ -285,15 +294,15 @@ class Invoice(MWRAPBase):
         :param tax: Tax percent (between 0.0 and 100.0)
         :param currency: Currency code (e.g. EUR)
         :param items: Invoice items
-        :param status: State of the invoice (default: "created")
-        :param change_address: Address propagation (default: "invoice")
-        :param salutation: Salutation text
-        :param footer: Footer text
-        :param discount: Discount in percent (between 0.0 and 100.0)
-        :param cash_discount: Cash discount in percent (between 0.0 and 100.0)
-        :param cash_discount_days: How many days is the cash discount valid (ex. 4)
-        :param project_id: Id of the project the invoice belongs to
-        :param tags: List of tags
+        :param status: State of the invoice (default :attr:`.InvoiceStatus.CREATED`)
+        :param change_address: Address propagation (default :attr:`.InvoiceChangeAddress.INVOICE`)
+        :param salutation: Salutation text (default ``None``)
+        :param footer: Footer text (default ``None``)
+        :param discount: Discount in percent (between 0.0 and 100.0) (default ``None``)
+        :param cash_discount: Cash discount in percent (between 0.0 and 100.0) (default ``None``)
+        :param cash_discount_days: How many days is the cash discount valid (ex. 4) (default ``None``)
+        :param project_id: Id of the project the invoice belongs to (default ``None``)
+        :param tags: List of tags (default ``[]``)
 
         :type customer_id: int
         :type recipient_address: str
@@ -316,10 +325,11 @@ class Invoice(MWRAPBase):
         :type tags: list
 
         :returns: The created invoice
-
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
 
         .. note::
-            Note that if you create an invoice with a project, that project must also belong to the customer the invoice was created for.
+            Note that if you create an invoice with a project, that project must also belong to the customer the invoice
+            was created for.
 
         .. seealso::
 
