@@ -1,10 +1,11 @@
 from moco_wrapper.models.base import MWRAPBase
 from moco_wrapper.const import API_PATH
 
+
 class ProjectContract(MWRAPBase):
     """
     Class for handling project contracts.
-    
+
     When a user gets assigned to a project, that is called a project contract. This can be done with this model.
     """
 
@@ -24,16 +25,16 @@ class ProjectContract(MWRAPBase):
         active: bool = None,
         budget: float = None,
         hourly_rate: float = None
-        ):
+    ):
         """
         Assign a user to a project.
 
         :param project_id: Id of the project
         :param user_id: User id of the person to assign
-        :param billable: If the contract is billable
-        :param active: If the contract is active
-        :param budget: Contract budget
-        :param hourly_rate: Contract hourly rate
+        :param billable: If the contract is billable (default ``None``)
+        :param active: If the contract is active (default ``None``)
+        :param budget: Contract budget (default ``None``)
+        :param hourly_rate: Contract hourly rate (default ``None``)
 
         :type project_id: int
         :type user_id: int
@@ -43,6 +44,7 @@ class ProjectContract(MWRAPBase):
         :type hourly_rate: float
 
         :returns: Created contract object
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
         data = {
             "user_id": user_id
@@ -63,33 +65,34 @@ class ProjectContract(MWRAPBase):
         self,
         project_id: int,
         contract_id: int,
-        billable: bool= None,
+        billable: bool = None,
         active: bool = None,
         budget: float = None,
         hourly_rate: float = None
-        ):
+    ):
         """
         Update an existing project contract.
 
         :param project_id: Id of the project to update the contract for
         :param contract_id: Id of the contract to update
-        :param billable: If the contract is billable
-        :param active: If the contract is active
-        :param budget: Contract budget
-        :param hourly_rate: Contract hourly rate
+        :param billable: If the contract is billable (default ``None``)
+        :param active: If the contract is active (default ``None``)
+        :param budget: Contract budget (default ``None``)
+        :param hourly_rate: Contract hourly rate (default ``None``)
 
         :type project_id: int
-        :type contact_id: int
+        :type contract_id: int
         :type billable: bool
         :type active: bool
         :type budget: float
         :type hourly_rate: float
 
         :returns: The updated project contract
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         data = {}
-        for key,value in (
+        for key, value in (
             ("billable", billable),
             ("active", active),
             ("budget", budget),
@@ -98,13 +101,14 @@ class ProjectContract(MWRAPBase):
             if value is not None:
                 data[key] = value
 
-        return self._moco.put(API_PATH["project_contract_update"].format(project_id=project_id, contract_id=contract_id), data=data)
+        return self._moco.put(
+            API_PATH["project_contract_update"].format(project_id=project_id, contract_id=contract_id), data=data)
 
     def get(
         self,
         project_id: int,
         contract_id: int
-        ):
+    ):
         """
         Retrieve a project contract.
 
@@ -115,6 +119,7 @@ class ProjectContract(MWRAPBase):
         :type contract_id: int
 
         :returns: The contract object
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         return self._moco.get(API_PATH["project_contract_get"].format(project_id=project_id, contract_id=contract_id))
@@ -125,14 +130,14 @@ class ProjectContract(MWRAPBase):
         sort_by: str = None,
         sort_order: str = 'asc',
         page: int = 1
-        ):
+    ):
         """
         Retrieve all active contracts for a project.
 
         :param project_id: Id of the project
-        :param sort_by: Sort by field
-        :param sort_order: asc or desc (default asc)
-        :param page: Page number (default 1)
+        :param sort_by: Sort by field (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
+        :param page: Page number (default ``1``)
 
         :type project_id: int
         :type sort_by: str
@@ -140,6 +145,7 @@ class ProjectContract(MWRAPBase):
         :type page: int
 
         :returns: List of contract objects
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
 
         params = {}
@@ -159,11 +165,12 @@ class ProjectContract(MWRAPBase):
         self,
         project_id: int,
         contract_id: int,
-        ):
+    ):
         """
         Delete a project contract.
 
-        Deleting a staff assignment is only possible as long as there no hours tracked from the assinged person for the project.
+        Deleting a staff assignment is only possible as long as there no hours tracked from the assigned person for
+        the project.
 
         :param project_id: Id of the project
         :param contract_id: Id of the contract to delete
@@ -172,6 +179,8 @@ class ProjectContract(MWRAPBase):
         :type contract_id: int
 
         :returns: Empty response on success
+        :rtype: :class:`moco_wrapper.util.response.EmptyResponse`
         """
 
-        return self._moco.delete(API_PATH["project_contract_delete"].format(project_id=project_id, contract_id=contract_id))
+        return self._moco.delete(
+            API_PATH["project_contract_delete"].format(project_id=project_id, contract_id=contract_id))
