@@ -1,6 +1,4 @@
-import datetime
-
-from moco_wrapper.models.base import MWRAPBase  
+from moco_wrapper.models.base import MWRAPBase
 from moco_wrapper.const import API_PATH
 
 
@@ -20,15 +18,16 @@ class PurchaseCategory(MWRAPBase):
     def get(
         self,
         category_id: int
-        ):
+    ):
         """
-        Retrieve a single category
+        Retrieve a single category.
 
         :param category_id: Id of the category to retrieve
 
         :type category_id: int
 
         :returns: Single Category object
+        :rtype: :class:`moco_wrapper.util.response.JsonResponse`
         """
 
         return self._moco.get(API_PATH["purchase_category_get"].format(id=category_id))
@@ -37,27 +36,28 @@ class PurchaseCategory(MWRAPBase):
         self,
         sort_by: str = None,
         sort_order: str = 'asc',
-        page = 1
-        ):
+        page: int = 1
+    ):
         """
-        Retrieve a list of catogories
+        Retrieve a list of categories.
+
+        :param sort_by: Sort by field (default ``None``)
+        :param sort_order: asc or desc (default ``"asc"``)
+        :param page: Page number (default ``1``)
 
-        :param sort_by: Sort by field
-        :param sort_order: asc or desc
-        :param page: Page number
-        
         :type sort_by: str
         :type sort_order: str
         :type page: int
 
         :returns: List of categories
+        :rtype: :class:`moco_wrapper.util.response.ListingResponse`
         """
 
         params = {
-            "page" : page
+            "page": page
         }
-        
+
         if sort_by is not None:
             params["sort_by"] = "{} {}".format(sort_by, sort_order)
 
-        return self._moco.get(API_PATH["purchase_category_getlist"], params=params)
\ No newline at end of file
+        return self._moco.get(API_PATH["purchase_category_getlist"], params=params)
